summaryrefslogtreecommitdiff
path: root/indra/newview/llimview.cpp
diff options
context:
space:
mode:
authorLoren Shih <seraph@lindenlab.com>2010-07-01 11:11:00 -0400
committerLoren Shih <seraph@lindenlab.com>2010-07-01 11:11:00 -0400
commita94223b3dfb7e2a12e6ab850aac096f1d8301ad3 (patch)
treef83023fc60578dcad06b398d53c55d283bf4d19a /indra/newview/llimview.cpp
parent1cdf3146f284eb5a2c9effc6b44f060b5345f58b (diff)
parentaf4a85009011119e7787e2b30416919117edccf9 (diff)
automated merge
Diffstat (limited to 'indra/newview/llimview.cpp')
-rw-r--r--indra/newview/llimview.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/indra/newview/llimview.cpp b/indra/newview/llimview.cpp
index 6d3998bb96..a2b72e7d74 100644
--- a/indra/newview/llimview.cpp
+++ b/indra/newview/llimview.cpp
@@ -1929,9 +1929,9 @@ BOOL LLIncomingCallDialog::postBuild()
mLifetimeTimer.stop();
}
//it's not possible to connect to existing Ad-Hoc chat through incoming ad-hoc call
//and no IM for avaline
- childSetVisible("Start IM", is_avatar && notify_box_type != "VoiceInviteAdHoc");
+ childSetVisible("Start IM", is_avatar && notify_box_type != "VoiceInviteAdHoc" && notify_box_type != "VoiceInviteGroup");
setCanDrag(FALSE);
@@ -1929,9 +1929,9 @@ BOOL LLIncomingCallDialog::postBuild()
mLifetimeTimer.stop();
}
- //it's not possible to connect to existing Ad-Hoc chat through incoming ad-hoc call
+ //it's not possible to connect to existing Ad-Hoc/Group chat through incoming ad-hoc call
//and no IM for avaline